@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..1\n"; }
+BEGIN { $| = 1; print "1..3\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use MemHandle;
 $loaded = 1;
@@ -18,3 +18,23 @@ print "ok 1\n";
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
 
+use IO::Seekable;
+
+my $num=2;
+my $mh = new MemHandle;
+my $teststr = 'testorama';
+print $mh $teststr;
+goto FAIL if $mh->mem() ne $teststr;
+print "ok ${\($num++)}\n";
+
+$mh->seek( 0, SEEK_SET );
+goto FAIL if $teststr ne <$mh>;
+
+PASS:
+print "ok $num\n";
+exit( 0 );
+
+FAIL:
+    print 'not ';
+goto PASS;
+#print "end\n";
